Temporal progression of landslide warning state
viz_landslide_warnings_from_to(
data,
district = NULL,
province = NULL,
interactivity = TRUE,
ang = 90
)Heatmap plot of landslide warnings
name of the dataset, by default ditwah_landslides_warnings
District name or All, if no district put NULL
Province name or All, if no province put NULL
if TRUE interactive plot will be generated, if FALSE static plot will be generated
angle of the x-axis lables
Thiyanga S. Talagala, Geethma R. Jayasinghe, Y. M. Amali P. Rajapaksha